@@ -131,6 +131,10 @@ gint toggle_fullscreen_cb (tilda_window *tw)
 		gtk_window_unfullscreen (GTK_WINDOW (tw->window));
 		tw->fullscreen = FALSE;
 	}
+
+    // It worked. Having this return GDK_EVENT_STOP makes the callback not carry the
+    // keystroke into the vte terminal widget.
+    return GDK_EVENT_STOP;
 }
 
 
@@ -364,7 +368,7 @@ static gboolean goto_tab_generic (tilda_window *tw, gint tab_number)
 
     if (g_list_length (tw->terms) > (tab_number-1))
     {
-        goto_tab (tw, g_list_length (tw->terms) - tab_number);
+        goto_tab (tw, tab_number - 1);
         return TRUE;
     }
 
@@ -586,6 +590,7 @@ tilda_window *tilda_window_init (const gchar *config_file, const gint instance)
     gtk_notebook_set_show_tabs (GTK_NOTEBOOK(tw->notebook), FALSE);
     gtk_notebook_set_show_border (GTK_NOTEBOOK (tw->notebook),
         config_getbool("notebook_border"));
+    gtk_notebook_set_scrollable (GTK_NOTEBOOK(tw->notebook), TRUE);
     tilda_window_set_tab_position (tw, config_getint ("tab_pos"));
 
     provider = gtk_css_provider_new ();
